Samyro
=======================

An automatic poetry organizer built on `TensorFlow <http://tensorflow.org>`_'s
RNNs.

Samyro learns a text style from examples, saving
checkpoints, and generating new text segments from those samples.
Derived from example code built for PrettyTensor.

"Samyro" was the first pseudonym of Samuel (Samy) Rosenstock, better
known by his later pseudonym `Tristan Tzara
<http://en.wikipedia.org/Tristan_Tzara>`_. (`tzara` was already taken
on pypi.)
